@@ -470,7 +470,8 @@ class ChainlitAdapter(SDKAdapter):
     def aggregate_tool_calls_stream(
         self,
         tool_calls: Optional[Dict[int, ToolCall]] = None,
-        tool_call_requests: Optional[List[Any]] = None
+        tool_call_requests: Optional[List[Any]] = None,
+        completion_response: Any
 
     ) -> Dict[int, ToolCall]:
         """
@@ -500,7 +501,7 @@ class ChainlitAdapter(SDKAdapter):
         
         return tool_calls
 
-    @cl.step(type="tool", name="xpander.ai")
+    @cl.step(type="tool", name="xpander-ai")
     async def process_tool_calls(self, tool_calls: Dict[int, ToolCall], on_tool_call: Optional[Callable], local_tools: Dict[str, Callable] = None) -> str | None:
         """
         Process tool calls by formatting their payloads and executing them.
@@ -510,6 +511,9 @@ class ChainlitAdapter(SDKAdapter):
         """
         
         current_execution = self.agent.execution.to_dict()
+        user_settings = cl.user_session.get("user_settings",{})
+        is_debug_mode_active = user_settings.get("debug_mode", True)
+        
         is_sub_agent = True if "parentExecution" in current_execution and current_execution['parentExecution'] else False
         
         for tc in tool_calls.values():
@@ -539,14 +543,26 @@ class ChainlitAdapter(SDKAdapter):
             is_agent_end_tool = True if tool_call.name == AGENT_END_TOOL else False
             
             current_step = cl.context.current_step
+            if not is_debug_mode_active:
+                current_step.name = "xpander-ai"
+                current_step.show_input = False
+            
+            graph_item = self.agent.graph.find_node_by_item_id(item_id=tool_call.name)
+            tool_name = graph_item.name if graph_item else tool_call.name
             
-            tool_name = tool_call.name
             
             tool_agent_id = get_sub_agent_id_from_oas_by_name(agent_name=tool_call.name,oas=self.agent.oas)
             if tool_agent_id:
                 sub_agent_node = self.agent.graph.find_node_by_item_id(item_id=tool_agent_id)
                 if sub_agent_node:
+                    if on_tool_call:
+                        await on_tool_call(tool_call=tool_call,graph_item=sub_agent_node)
                     tool_name = sub_agent_node.name
+            else:
+                # report to parent window
+                graph_item = self.agent.graph.find_node_by_item_id(item_id=tool_call.name)
+                if graph_item and on_tool_call:
+                    await on_tool_call(tool_call=tool_call,graph_item=graph_item)
                     
             if is_sub_agent:
                 if is_agent_end_tool:
@@ -557,8 +573,9 @@ class ChainlitAdapter(SDKAdapter):
             elif is_agent_end_tool:
                 tool_name = f"Crafting final answer"
             
-            current_step.name = tool_name
-            current_step.input = tool_call.payload
+            if is_debug_mode_active:
+                current_step.name = tool_name
+                current_step.input = tool_call.payload
             
             # handle local tools
             if tool_call.type == ToolCallType.LOCAL:
@@ -580,34 +597,30 @@ class ChainlitAdapter(SDKAdapter):
                 except Exception as e:
                     tool_call_result.result = str(e)
                     tool_call_result.is_error = True
-                    current_step.is_error = True
+                    if is_debug_mode_active:
+                        current_step.is_error = True
                 
                 
                 # report result to the memory
                 self.agent.add_tool_call_results(tool_call_results=[tool_call_result])
             else:
-                
-                # report to parent window
-                graph_item = self.agent.graph.find_node_by_item_id(item_id=tool_call.name)
-                if graph_item and on_tool_call:
-                    await on_tool_call(tool_call=tool_call,graph_item=graph_item)
-                    
                 tool_call_result = self.agent.run_tool(tool=tool_call, payload_extension={"headers":{"x-xpander-source-node-type": SourceNodeType.ASSISTANT.value.lower()}})
             
-            if tool_call_result.result == "STOP":
-                    current_step.name = f"Waiting for human approval ({tool_name})"
-            
-            if is_agent_end_tool:
-                current_step.output = tool_call_result.payload['bodyParams']['result']
-                current_step.language = "text"
-            else:
-                current_step.output = tool_call_result.result
-                current_step.language = "json"
+            if is_debug_mode_active:
+                if is_agent_end_tool:
+                    current_step.output = tool_call_result.payload['bodyParams']['result']
+                    current_step.language = "text"
+                else:
+                    current_step.output = tool_call_result.result
+                    current_step.language = "json"
                     
-            if is_agent_end_tool and not is_sub_agent:
-                await current_step.remove()
-                tool_calls.clear()
-                return tool_call_result.payload['bodyParams']['result']
+                if tool_call_result.result == "STOP":
+                        current_step.name = f"Waiting for human approval ({tool_name})"
+                        current_step.output = None
+                if is_agent_end_tool and not is_sub_agent:
+                    await current_step.remove()
+                    tool_calls.clear()
+                    return tool_call_result.payload['bodyParams']['result']
 
         # Reset tool calls
         tool_calls.clear()
